var xml2js = require('xml2js'),
	request = require('request');

/*

https://api.esendex.com/v1.0/session/constructor

<?xml version="1.0" encoding="utf-8"?> 
<session> 
  <id>1183C73D-2E62-4F60-B610-30F160BDFBD5</id>
</session>

*/

var Session = function(sessionId) {
	this.sessionId = sessionId;
};
Session.prototype.toAuthorization = function () {
	return "Basic " + new Buffer(this.sessionId).toString("base64");
};

var SessionService = function (apiHost) {
	if (apiHost === undefined)
		apiHost = "https://api.esendex.com";
		
	this.apiHost = apiHost;
	
	this.dependencies = {
		request: request,
		xml2js: xml2js
	};
};
SessionService.prototype.create = function (username, password, callback) {
	if (username === undefined || typeof username !== "string")
		throw "username must be supplied, and be a string";
	if (password === undefined || typeof username !== "string")
		throw "password must be supplied, and be a string";
	if (callback === undefined || typeof callback !== "function")
		throw "callback must be supplied, and be a function";
		
	var authorization = "Basic " + new Buffer(username + ":" + password).toString("base64");
	var $this = this;
	
	$this.dependencies.request({
			uri: $this.apiHost + "/v1.0/session/constructor",
			headers: { "Authorization": authorization },
			method: "POST"
		},
		function (error, response, body) {
			$this.handlerSessionConstructorResponse(error, response, body, callback);
		}
	);
};
SessionService.prototype.handlerSessionConstructorResponse = function (error, response, body, callback) {
	if (error) 
		throw "Session failed to communicate with API service: " + error;
	if (!error && response.statusCode != 200) 
		throw "Session service returned an error: " + response.statusCode;

	var parser = new this.dependencies.xml2js.Parser();
	parser.on('end', function(result) {
		callback(new Session(result.session.id[0]));
	});
	
	parser.parseString(body);
};

module.exports = SessionService;