var sinon = require('sinon'),
	assert = require('assert');
	
var sdk = require('../');

describe('MessageDispatcherService', function () {
	describe('#send()', function () {
	
		it('should build the xml request body', function () {
		
			var xmlbuilder = require('xmlbuilder'),
				request = require('request');
		
			var testRoot = xmlbuilder.create("test");
		
			var elementStub = sinon.stub(testRoot, 'element').returns('not an element');
			var endStub = sinon.stub(testRoot, 'end').returns('also not an element');
			
			var xmlbuilderStub = sinon.stub(xmlbuilder, 'create').returns(testRoot);
			var requestStub = sinon.stub();
			
			var mockSession = { sessionId: "a session id", toAuthorization: function () { } };

			var service = new sdk.MessageDispatcherService("a host", mockSession);
			service.dependencies.xmlbuilder = xmlbuilder;
			service.dependencies.request = requestStub;
			
			service.send([], "account ref");
			
			sinon.assert.called(xmlbuilderStub);
			
			xmlbuilderStub.restore();
		});
		
		it('should create a request to the message dispatcher endpoint', function () {
				
			var requestSpy = sinon.spy();
			
			var auth = '12345';
			var host = 'a host';
			var sessionAuthStub = sinon.stub().returns(auth);
			var mockSession = { sessionId: "a session id", toAuthorization: sessionAuthStub };
			var accountRef = "account ref";
			var expectedRequest = {
				uri: host + "/v1.0/messagedispatcher",
				headers: { "Authorization": auth },
				method: "POST",
				body: '<?xml version="1.0"?><messages><accountreference>' + accountRef + '</accountreference></messages>'
			};

			var service = new sdk.MessageDispatcherService(host, mockSession);
			service.dependencies.request = requestSpy;
			
			service.send([], accountRef);
			
			sinon.assert.calledOnce(sessionAuthStub);
			sinon.assert.calledWith(requestSpy, expectedRequest, sinon.match.func);
		});
	
	});
	
	describe('#schedule()', function () {
	
	
	
	});
});